@@ -46,3 +46,17 @@ pub fn date_string(x: u32) -> String {
     let fill = |x: u32| if x > 9 { "" } else { "0" };
     format!("{}-{}{}-{}{}", y, fill(m), m, fill(d), d)
 }
+
+#[cfg(feature = "serde")]
+#[cfg_attr(docsrs, doc(cfg(feature = "serde")))]
+pub fn ser_date_string<S>(date: &u32, serializer: S) -> Result<S::Ok, S::Error>
+    where S: serde::Serializer {
+    serializer.serialize_str(&crate::bytes_helper::date_string(*date))
+}
+
+#[cfg(feature = "serde")]
+#[cfg_attr(docsrs, doc(cfg(feature = "serde")))]
+pub fn ser_code_string<S>(code: &u32, serializer: S) -> Result<S::Ok, S::Error>
+    where S: serde::Serializer {
+    serializer.serialize_str(&format!("{:06}", code))
+}
