@@ -1,4 +1,4 @@
-#![doc(html_root_url = "https://docs.rs/rustdx/0.2.4")]
+#![doc(html_root_url = "https://docs.rs/rustdx/0.2.5")]
 #![cfg_attr(docsrs, feature(doc_cfg))]
 // #![feature(test)]
 // extern crate test;
@@ -9,10 +9,6 @@ pub mod bytes_helper;
 #[cfg_attr(docsrs, doc(cfg(feature = "file")))]
 pub mod file;
 
-#[cfg(feature = "serde")]
-#[cfg_attr(docsrs, doc(cfg(feature = "serde")))]
-pub mod serde_type;
-
 #[cfg(feature = "tcp")]
 #[cfg_attr(docsrs, doc(cfg(feature = "tcp")))]
 pub mod tcp;
